@@ -1,7 +1,10 @@
-import json
-
 import html5lib
 
+try:
+    import json
+except ImportError:
+    import simplejson as json
+
 
 def get_items(location):
     """
@@ -17,15 +20,17 @@ def get_items(location):
 class Item(object):
     """
     A class for representing a microdata Item. Item properties are accessible 
-    as standard Python properties, which returns the either a unicode string
-    or another Item, if there is a nested Item.
+    as standard Python properties, which return either a unicode string
+    or another Item.
     """
 
     def __init__(self, itemtype=None, itemid=None):
         """Create an Item, by optionally passing in an itemtype URL
         """
-        self.itemtype = itemtype
-        self.itemid = itemid
+        if itemtype:
+            self.itemtype = URI(itemtype)
+        if itemid:
+            self.itemid = URI(itemid)
         self.props = {}
 
     def __getattr__(self, name):
@@ -70,85 +75,37 @@ class Item(object):
         i = {}
 
         if self.itemtype:
-            i['$itemtype'] = self.itemtype
+            i['$itemtype'] = self.itemtype.string
         if self.itemid:
-            i['$itemid'] = self.itemid 
+            i['$itemid'] = self.itemid.string
 
         for prop, values in self.props.items():
             i[prop]= []
             for v in values:
                 if isinstance(v, Item):
                     i[prop].append(v.json_dict())
+                elif isinstance(v, URI):
+                    i[prop].append(v.string)
                 else:
                     i[prop].append(v)
         return i
 
 
-def _find_items(e):
-    items = []
-    if _is_element(e) and e.hasAttribute("itemscope"):
-        item = _get_item(e)
-        if item: 
-            items.append(item)
-    else:
-        for child in e.childNodes:
-            items.extend(_find_items(child))
-    return items
+class URI(object):
+
+    def __init__(self, string):
+        self.string = string
+
+    def __eq__(self, other):
+        if isinstance(other, URI):
+            return self.string == other.string
+        return False
+
+    def __repr__(self):
+        return self.string
 
 
-def _get_item(e, item=None):
-    if not item:
-        item = Item(_attr(e, "itemtype"), _attr(e, "itemid"))
-
-
-    for child in e.childNodes:
-        prop_name = _attr(child, "itemprop")
-        if prop_name and _is_itemscope(child):
-            value = _get_item(child)
-            item.set(prop_name, value)
-        elif prop_name:
-            value = _property_value(child)
-            item.set(prop_name, value)
-        else:
-            _get_item(child, item)
-
-    return item
-
-
-def _attr(e, name):
-    if _is_element(e) and e.hasAttribute(name):
-        return e.getAttribute(name)
-    return None
-
-
-def _is_element(e):
-    return e.nodeType == e.ELEMENT_NODE
-
-
-def _is_itemscope(e):
-    return _attr(e, "itemscope") is not None
-
-
-def _property_value(e):
-    value = None
-    attrib = property_values.get(e.tagName, None)
-    if attrib:
-        value = e.getAttribute(attrib)
-    else:
-        value = _text(e)
-    return value
-
-
-def _text(e):
-    chunks = []
-    if e.nodeType == e.TEXT_NODE:
-        chunks.append(e.data)
-    for child in e.childNodes:
-        chunks.append(_text(child))
-    return ''.join(chunks)
-
-
-# where to look for property values if it isn't in the element text
+# what follows are the guts of extracting the Items from a DOM
 
 property_values = {
     'meta':     'content',
@@ -164,3 +121,63 @@ property_values = {
     'object':   'data',
     'time':     'datetime',
 }
+
+def _find_items(e):
+    items = []
+    if _is_element(e) and e.hasAttribute("itemscope"):
+        item = _get_item(e)
+        if item: 
+            items.append(item)
+    else:
+        for child in e.childNodes:
+            items.extend(_find_items(child))
+    return items
+
+def _get_item(e, item=None):
+    if not item:
+        item = Item(_attr(e, "itemtype"), _attr(e, "itemid"))
+
+    for child in e.childNodes:
+        prop_name = _attr(child, "itemprop")
+        if prop_name and _is_itemscope(child):
+            value = _get_item(child)
+            item.set(prop_name, value)
+        elif prop_name:
+            value = _property_value(child)
+            item.set(prop_name, value)
+        else:
+            _get_item(child, item)
+
+    return item
+
+# helper functions around python's minidom
+
+def _attr(e, name):
+    if _is_element(e) and e.hasAttribute(name):
+        return e.getAttribute(name)
+    return None
+
+def _is_element(e):
+    return e.nodeType == e.ELEMENT_NODE
+
+def _is_itemscope(e):
+    return _attr(e, "itemscope") is not None
+
+def _property_value(e):
+    value = None
+    attrib = property_values.get(e.tagName, None)
+    if attrib in ["href", "src"]:
+        value = URI(e.getAttribute(attrib)) 
+    elif attrib:
+        value = e.getAttribute(attrib)
+    else:
+        value = _text(e)
+    return value
+
+def _text(e):
+    chunks = []
+    if e.nodeType == e.TEXT_NODE:
+        chunks.append(e.data)
+    for child in e.childNodes:
+        chunks.append(_text(child))
+    return ''.join(chunks)
